searchData={"content_type":"text/markdown","items":[{"doc":"Tracing features for elixir apps.\n\nJust call `use HatchTracing` in a module and you're good to go.\n\nYou'll probably just need to use the `span` functions, as the other functions\nare here just for compatibility. Check the `Usage` section below.\n\nAll other functions in this module have the same name and arity from\n`OpenTelemetry.Tracer`. Whenever possible, these functions will actually be\n`defdelegate`. When not possible, this means that some quality-of-life was\nadded before calling the corresponding `OpenTelemetry.Tracer` function.","ref":"HatchTracing.html","title":"HatchTracing","type":"module"},{"doc":"When you `use HatchTracing` it will include all required modules to start\nusing tracing, as well as importing the `span/1`, `span/2` and `span/3`\nfunctions.\n\n```elixir\ndefmodule MyModule do\n  use HatchTracing\n\n  def my_function do\n    span do\n      # ... some code here\n    end\n  end\nend\n```","ref":"HatchTracing.html#module-usage","title":"Usage - HatchTracing","type":"module"},{"doc":"By default, if no name is specified, the generated span name will include the\nmodule, function name and function arity.\n\n```\nHatch.Portal.UseCases.Xablau.call/1\n```\n\nWhen adding custom names, keep in mind the official guideline for span names.\n\nThe span name concisely identifies the work represented by the Span, for\nexample, an RPC method name, a function name, or the name of a subtask or\nstage within a larger computation. The span name SHOULD be the most general\nstring that identifies a (statistically) interesting class of Spans, rather\nthan individual Span instances while still being human-readable. That is,\n“get_user” is a reasonable name, while “get_user/314159”, where “314159” is a\nuser ID, is not a good name due to its high cardinality. Generality SHOULD be\nprioritized over human-readability, like “get_account/{accountId}”.","ref":"HatchTracing.html#module-on-span-names","title":"On Span Names - HatchTracing","type":"module"},{"doc":"Setup the target module to use tracing tools.\n\nIt will also import the `span` function for a quickstart.","ref":"HatchTracing.html#__using__/1","title":"HatchTracing.__using__/1","type":"macro"},{"doc":"Add an event to the currently active Span.\n\nAn event is a human-readable message on a span that represents “something\nhappening” during it’s lifetime. For example, imagine a function that requires\nexclusive access to a resource that is under a mutex. An event could be\ncreated at two points - once, when we try to gain access to the resource, and\nanother when we acquire the mutex.\n\nA useful characteristic of events is that their timestamps are displayed as\noffsets from the beginning of the span, allowing you to easily see how much\ntime elapsed between them.\n\nEvents can also have attributes of their own.\n\nReference:\nhttps://opentelemetry.io/docs/reference/specification/trace/api/#add-events","ref":"HatchTracing.html#add_event/2","title":"HatchTracing.add_event/2","type":"function"},{"doc":"Add a list of events to the currently active Span.\n\nSee also `add_event/2`.\n\nReference:\nhttps://opentelemetry.io/docs/reference/specification/trace/api/#add-events","ref":"HatchTracing.html#add_events/1","title":"HatchTracing.add_events/1","type":"function"},{"doc":"Generate a valid start_opts map to start a trace.\n\nWhen overriding, make sure that the value is correct, as this function does\nnot perform any checks.\n\nAccepted keys: :kind, :attributes, :links, :start_time, and :is_recording.","ref":"HatchTracing.html#build_span_opts/1","title":"HatchTracing.build_span_opts/1","type":"function"},{"doc":"Returns the currently active `t:OpenTelemetry.span_ctx/0`.","ref":"HatchTracing.html#current_span_ctx/0","title":"HatchTracing.current_span_ctx/0","type":"function"},{"doc":"Returns the `t:OpenTelemetry.span_ctx/0` active in Context `ctx`.","ref":"HatchTracing.html#current_span_ctx/1","title":"HatchTracing.current_span_ctx/1","type":"function"},{"doc":"End the currently active Span and sets its end timestamp.\nThis has no effect on any child Spans that may exist of this Span.\n\nTo end a specific span, see `OpenTelemetry.Span.end_span/1`.\n\nThe Span in the current Context has its `is_recording` set to `false`.","ref":"HatchTracing.html#end_span/1","title":"HatchTracing.end_span/1","type":"function"},{"doc":"","ref":"HatchTracing.html#is_ast/1","title":"HatchTracing.is_ast/1","type":"macro"},{"doc":"Record an exception as an event, following the semantics convetions for exceptions.\n\nIf trace is not provided, the stacktrace is retrieved from `Process.info/2`","ref":"HatchTracing.html#record_exception/3","title":"HatchTracing.record_exception/3","type":"function"},{"doc":"Set an attribute with key and value on the currently active Span.\n\nAttributes are keys and values that are applied as metadata to your spans and\nare useful for aggregating, filtering, and grouping traces. Attributes can be\nadded at span creation, or at any other time during the lifecycle of a span\nbefore it has completed.\n\nIf the value is a set (map, list or tuple), its value is converted to a format\nthat is supported by OpenTelemetryApi.\n\nReference:\nhttps://opentelemetry.io/docs/reference/specification/common/attribute-naming/","ref":"HatchTracing.html#set_attribute/2","title":"HatchTracing.set_attribute/2","type":"function"},{"doc":"Add a list of attributes to the currently active Span.\n\nThe list of attributes can be a plain list, keyword lists, maps or tuples.\n\nReference:\nhttps://opentelemetry.io/docs/reference/specification/common/attribute-naming/","ref":"HatchTracing.html#set_attributes/2","title":"HatchTracing.set_attributes/2","type":"function"},{"doc":"Takes a `t:OpenTelemetry.span_ctx/0` and the Tracer sets it to the currently\nactive Span.","ref":"HatchTracing.html#set_current_span/1","title":"HatchTracing.set_current_span/1","type":"function"},{"doc":"Takes a `t:OpenTelemetry.Ctx.t/0` and the `t:OpenTelemetry.span_ctx/0` and the\nTracer sets it to the current span in the pass Context.","ref":"HatchTracing.html#set_current_span/2","title":"HatchTracing.set_current_span/2","type":"function"},{"doc":"Creates and sets the Status of the currently active Span.\n\nIf used, this will override the default Span Status, which is `:unset`.\n\nReference:\nhttps://opentelemetry.io/docs/reference/specification/trace/api/#set-status","ref":"HatchTracing.html#set_status/2","title":"HatchTracing.set_status/2","type":"function"},{"doc":"This is a custom and simpler version of `with_span`.\n\nThe order of parameters is slightly different in order to favour automatic\nname generation.\n\n- start_opts: a map with starting options. Check the `start_otps/1` function\n  for more information\n- name: a string with the name of the span (default to nil). When nil, the\n  name will be automatically generated based on the caller context (module +\n  function)\n\nCreates a new span which is set to the currently active Span in the Context of\nthe block. The Span is ended automatically when the `block` completes and the\nContext is what it was before the block.\n\nIf the name is `nil`, a span name is automatically generated based on the\nmodule and function that started the span, like\n`Hatch.Portal.UseCases.Xablau.call/1`.","ref":"HatchTracing.html#span/3","title":"HatchTracing.span/3","type":"macro"},{"doc":"Starts a new span and does not make it the current active span of the current\nprocess.\n\nThe current active Span is used as the parent of the created Span.\n\nA Span represents a single operation within a trace. Spans can be nested to\nform a trace tree. Each trace contains a root span, which typically describes\nthe entire operation and, optionally, one or more sub-spans for its\nsub-operations.\n\nReferece:\nhttps://opentelemetry.io/docs/reference/specification/trace/api/#span","ref":"HatchTracing.html#start_span/2","title":"HatchTracing.start_span/2","type":"macro"},{"doc":"Starts a new span and does not make it the current active span of the current\nprocess.\n\nThe current active Span is used as the parent of the created Span.\n\nA Span represents a single operation within a trace. Spans can be nested to\nform a trace tree. Each trace contains a root span, which typically describes\nthe entire operation and, optionally, one or more sub-spans for its\nsub-operations.\n\nReferece:\nhttps://opentelemetry.io/docs/reference/specification/trace/api/#span","ref":"HatchTracing.html#start_span/3","title":"HatchTracing.start_span/3","type":"macro"},{"doc":"Updates the Span name.\n\nIt is highly discouraged to update the name of a Span after its creation. Span\nname is often used to group, filter and identify the logical groups of spans.\nAnd often, filtering logic will be implemented before the Span creation for\nperformance reasons. Thus the name update may interfere with this logic.\n\nThe function name is called UpdateName to differentiate this function from the\nregular property setter. It emphasizes that this operation signifies a major\nchange for a Span and may lead to re-calculation of sampling or filtering\ndecisions made previously depending on the implementation.","ref":"HatchTracing.html#update_name/1","title":"HatchTracing.update_name/1","type":"function"},{"doc":"","ref":"HatchTracing.html#valid_name/1","title":"HatchTracing.valid_name/1","type":"macro"},{"doc":"","ref":"HatchTracing.html#valid_opts/1","title":"HatchTracing.valid_opts/1","type":"macro"},{"doc":"","ref":"HatchTracing.html#with_span/3","title":"HatchTracing.with_span/3","type":"macro"},{"doc":"Creates a new span which is set to the currently active Span in the Context of\nthe block. The Span is ended automatically when the `block` completes and the\nContext is what it was before the block.\n\nSee `start_span/2` and `end_span/0`.","ref":"HatchTracing.html#with_span/4","title":"HatchTracing.with_span/4","type":"macro"},{"doc":"# HatchTracing\n\nIt's a library that helps you to create `OpenTelemetry` spans with the least effort.\n\nWhen you `use HatchTracing` it will include all required modules to start using tracing,\nas well as importing the `span/1`, `span/2` and `span/3` functions.\n\n```elixir\ndefmodule MyModule do\n  use HatchTracing\n\n  def my_function do\n    span do\n      # ... some code here\n    end\n  end\nend\n```","ref":"readme.html","title":"HatchTracing","type":"extras"},{"doc":"The package can be installed by adding `hatch_tracing` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hatch_tracing, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation","title":"Installation - HatchTracing","type":"extras"},{"doc":"# Changelog for `hatch_tracing`","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Fix some type specs to match the expected by OpenTelemetry #6\n- Add a clause to accept only the `status_code` in `set_status/1` #7","ref":"changelog.html#v0-1-1","title":"v0.1.1 - Changelog","type":"extras"},{"doc":"First version!\n\n#","ref":"changelog.html#v0-1-0","title":"v0.1.0 - Changelog","type":"extras"},{"doc":"- OpenTelemetry helper functions","ref":"changelog.html#new-features","title":"New Features - Changelog","type":"extras"},{"doc":"Copyright 2023 Hatch\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"}]}